******************************
Welcome to Kanon documentation
******************************
.. currentmodule:: kanon.units.radices
.. include:: ../README.rst

Table of content
================

.. toctree::
  :caption: Documentation
  :maxdepth: 2

  tables/index.rst
  units/index.rst
  calendars/index.rst

.. include:: examples.rst

.. toctree::
  :caption: More info
  :maxdepth: 2

  changes.rst

Index and search
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
